<template>
  <div class="legend-container">
    <div class="legend-title">图例说明</div>
    <ul class="legend-list">
      <li v-for="(item, index) in legendItems" :key="index" class="legend-item">
        <img :src="getImageUrl(item.icon)" :alt="item.label" class="legend-icon" />
        <span class="legend-label">{{ item.label }}</span>
      </li>
    </ul>
  </div>
</template>

<script setup>
import { ref, onMounted } from "vue";

// 定义图例数据
const legendItems = ref([
  { icon: "编码器.png", label: "编码器" },
  { icon: "摄像头.png", label: "摄像头" },
  { icon: "泥位计.png", label: "泥位计" },
  { icon: "流速仪.png", label: "流速仪" },
  { icon: "含水率.png", label: "含水率" },
  { icon: "次生仪.png", label: "次生仪" },
  { icon: "雨量计.png", label: "雨量计" },
  { icon: "墒情.png", label: "墒情" },
]);

// 获取 public 下的图片路径
const getImageUrl = (iconName) => {
  return `/images/poi/${iconName}`;
};

onMounted(() => {
  console.log("这里是图例集合！");
});
</script>

<style lang="less" scoped>
.legend-container {
  padding: 0.5rem; // 减少内边距
  // background-color: #f9f9f9;
  border: 1px solid #ddd;
  border-radius: 8px;
  max-width: 100%;
  width: auto;
  font-size: clamp(10px, 1vw, 14px); // 更小的基础字号
}

.legend-title {
  width: 100%;
  // border: 1px solid #ddd;
  margin-bottom: 10%;
  text-align: center;
  letter-spacing: 2px;
  font-weight: 600;
  font-size: clamp(16px, 1vw, 20px); // 更小的基础字号

}

.legend-list {
  list-style: none;
  padding: 0;
  // margin: 0;
  display: flex;
  flex-direction: column; // 改为垂直方向布局
  gap: 0.5rem; // 减少间距
}

.legend-item {
  display: flex;
  align-items: center;
}

.legend-icon {
  width: 23px; // 减少图标大小
  height: 25px; // 减少图标大小
  margin-right: 0.5rem; // 减少右边距
}

.legend-label {
  font-size: inherit; // 继承父级字体大小
}
</style>